==> jcci-0.0.13.tar.gz: jcci-0.0.13/test/test_case.py <==
from src.jcci import jcci

#
# jcci.analyze('git@git.patsnap.com:platform/project-identity.git',
#              'master',
#              '92bdd486',
#              '3887d5c0', 'username1')
# # service and xnl
# jcci.analyze('git@git.patsnap.com:core-product/qa/libs/s-autotest-api-admin.git',
#              'master',
#              '9770b53',
#              'f4a166e', 'username1')

# jcci.analyze('git@git.patsnap.com:core-product/qa/libs/s-autotest-api-admin.git',
#              'master',
#              '73ca7b62e60d79eba018c5c8e4be90',
#              'b90b7387b735ba784a7cf316e8e153', 'username1')

# jcci.analyze('git@git.patsnap.com:core-product/qa/libs/s-autotest-api-admin.git',
#              'master',
#              '016f94b84b64',
#              '5c893f874892', 'username1')

# jcci.analyze('git@git.patsnap.com:core-product/backend/s-analytics-workspace.git',
#              'master',
#              'a0954b079cf39db14cd0c073ecd1d9146341b27d',
#              'bb779398cc45c2864a3566eed629d8806013d18e',
#              'username1')


# jcci.analyze('git@git.patsnap.com:core-product/backend/s-core-eureka.git',
#              'master',
#              '60562f1e',
#              '8f71adf7', 'username1')
#
# jcci.analyze('git@git.patsnap.com:platform/project-backoffice.git',
#              'master',
#              '090d7b7b',
#              'e9afe2ca', 'username1')
#


#
# jcci.analyze('git@git.patsnap.com:core-product/qa/libs/s-autotest-api-admin.git',
#              'master',
#              'c5c093d',
#              '7334f8e', 'username1')


jcci.analyze('git@gitee.com:chen-shaoxing/newgulimall.git',
             'master',
             '465c789',
             'c52d10d6442f', 'username1')

==> jcci-0.0.14.tar.gz: jcci-0.0.14/test/test_case.py <==
from src.jcci import jcci

#
# jcci.analyze('git@git.patsnap.com:platform/project-identity.git',
#              'master',
#              '92bdd486',
#              '3887d5c0', 'username1')
# # service and xnl
# jcci.analyze('git@git.patsnap.com:core-product/qa/libs/s-autotest-api-admin.git',
#              'master',
#              '9770b53',
#              'f4a166e', 'username1')

# jcci.analyze('git@git.patsnap.com:core-product/qa/libs/s-autotest-api-admin.git',
#              'master',
#              '73ca7b62e60d79eba018c5c8e4be90',
#              'b90b7387b735ba784a7cf316e8e153', 'username1')

# jcci.analyze('git@git.patsnap.com:core-product/qa/libs/s-autotest-api-admin.git',
#              'master',
#              '016f94b84b64',
#              '5c893f874892', 'username1')

# jcci.analyze('git@git.patsnap.com:core-product/backend/s-analytics-workspace.git',
#              'master',
#              'a0954b079cf39db14cd0c073ecd1d9146341b27d',
#              'bb779398cc45c2864a3566eed629d8806013d18e',
#              'username1')


# jcci.analyze('git@git.patsnap.com:core-product/backend/s-core-eureka.git',
#              'master',
#              '60562f1e',
#              '8f71adf7', 'username1')
#
# jcci.analyze('git@git.patsnap.com:platform/project-backoffice.git',
#              'master',
#              '090d7b7b',
#              'e9afe2ca', 'username1')
#


#
# jcci.analyze('git@git.patsnap.com:core-product/qa/libs/s-autotest-api-admin.git',
#              'master',
#              'c5c093d',
#              '7334f8e', 'username1')


jcci.analyze('git@gitee.com:chen-shaoxing/code-chain-demo.git',
             'master',
             'f82358d',
             'fd3adfb', 'username1')
